@@ -1,6 +1,5 @@
 import pytest
-
-from sdk.decorator import catch
+from ipa.decorator import catch
 
 
 def test_catch():
