@@ -1,4 +1,4 @@
-from sdk import add
+from ipa.math import add
 
 
 def test_add():
