@@ -1,6 +1,5 @@
 import pytest
-
-from sdk.util.lambda_util import invoke
+from ipa.func import invoke
 
 
 class A:
